#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dlist
version:              1.0
visibility:           public
id:                   dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
key:                  dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
license:              BSD-3-Clause
copyright:
    2006-2009 Don Stewart, 2013-2020 Sean Leather, 2017-2020 Oleg Grenrus, contributors

maintainer:           Sean Leather <sean.leather@gmail.com>
author:               Don Stewart
homepage:             https://github.com/spl/dlist
synopsis:             Difference lists
description:          List-like types supporting O(1) append and snoc operations.
category:             Data
abi:                  83070eb8d8188c1934acf2d42726f527
exposed:              True
exposed-modules:      Data.DList Data.DList.DNonEmpty Data.DList.Unsafe
hidden-modules:       Data.DList.Internal Data.DList.DNonEmpty.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dlist-1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dlist-1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dlist-1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dlist
hs-libraries:         HSdlist-1.0-B7D1vsARFiIHVaGk5CGbYO
depends:              base-4.18.2.1 deepseq-1.4.8.1
haddock-interfaces:   /usr/share/doc/haskell-dlist/html/dlist.haddock
haddock-html:         /usr/share/doc/haskell-dlist/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

